==> ome-files-platform-bundle-0.1.0-Release-Ubuntu14.04-x86_64-b5.tar.xz: ome-files-platform-bundle-0.1.0-Release-Ubuntu14.04-x86_64-b5/include/ome/xml/version.h <==
/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

#ifndef OME_XML_VERSION_H
#define OME_XML_VERSION_H

#include <string>

// Version metadata as integers

#define OME_XML_VERSION_MAJOR 5U
#define OME_XML_VERSION_MINOR 2U
#define OME_XML_VERSION_PATCH 0U

// Version metadata as strings

#define OME_XML_VERSION_MAJOR_S "5"
#define OME_XML_VERSION_MINOR_S "2"
#define OME_XML_VERSION_PATCH_S "0"
#define OME_XML_VERSION_EXTRA_S "-m2.5"
#ifndef OME_XML_VERSION_EXTRA_S
# define OME_XML_VERSION_EXTRA_S ""
#endif

// Revision number in version control
#define OME_XML_VCS_SHORTREVISION "None"
#define OME_XML_VCS_REVISION "9c20d9aef9ddd44bae3a1b48f7ef9a7f6a51dedf"

// Release date (seconds since the UNIX epoch)
#define OME_XML_VCS_DATE 1458915728

// Release date as ISO-8601 string
#define OME_XML_VCS_DATE_S "2016-03-25 14:22:08 +0000"

// Current OME model version used by xsd-fu
#define OME_XML_MODEL_VERSION "2013-06"

namespace ome
{
  namespace xml
  {

    /**
     * Get the current OME-XML model version.
     *
     * Note that unlike the OME_XML_MODEL_VERSION macro, which is the
     * version of the model which was built against, this gets the
     * version of the model of the library linked against (which might
     * differ).
     *
     * @returns the current OME-XML model version.
     */
    const std::string&
    model_version();

  }
}

#endif // OME_XML_VERSION_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */

==> ome-files-platform-bundle-0.3.1-Release-Ubuntu14.04-x86_64-b21.tar.xz: ome-files-platform-bundle-0.3.1-Release-Ubuntu14.04-x86_64-b21/include/ome/xml/version.h <==
/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

#ifndef OME_XML_VERSION_H
#define OME_XML_VERSION_H

#include <string>

// Version metadata as integers

#define OME_XML_VERSION_MAJOR 5U
#define OME_XML_VERSION_MINOR 5U
#define OME_XML_VERSION_PATCH 1U

// Version metadata as strings

#define OME_XML_VERSION_MAJOR_S "5"
#define OME_XML_VERSION_MINOR_S "5"
#define OME_XML_VERSION_PATCH_S "1"
#define OME_XML_VERSION_EXTRA_S ""
#ifndef OME_XML_VERSION_EXTRA_S
# define OME_XML_VERSION_EXTRA_S ""
#endif

// Current OME model version used by xsd-fu
#define OME_XML_MODEL_VERSION "2016-06"

namespace ome
{
  namespace xml
  {

    /**
     * Get the current OME-XML model version.
     *
     * Note that unlike the OME_XML_MODEL_VERSION macro, which is the
     * version of the model which was built against, this gets the
     * version of the model of the library linked against (which might
     * differ).
     *
     * @returns the current OME-XML model version.
     */
    const std::string&
    model_version();

  }
}

#endif // OME_XML_VERSION_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */
